@@ -1160,11 +1160,11 @@ bgpq_expand(struct bgpq_expander *b)
 		}
 	}
 
-	if (b->usesource) {
+	if (b->sources && b->sources[0] != 0) {
+		b->defaultsources = strdup(b->sources);
+	} else if (b->usesource) {
 		if (b->sources && b->sources[0] != 0) {
-			b->defaultsources = (char*)calloc(1, strlen(b->sources));
-			strlcpy(b->defaultsources, b->sources,
-			    sizeof(b->defaultsources));
+			b->defaultsources = strdup(b->sources);
 		} else {
 			b->defaultsources = bgpq_get_irrd_sources(b->fd);
 		}
