@@ -59,7 +59,8 @@ typedef enum {
 	V_NOKIA,
 	V_HUAWEI,
 	V_HUAWEI_XPL,
-	V_MIKROTIK,
+	V_MIKROTIK6,
+	V_MIKROTIK7,
 	V_NOKIA_MD,
 	V_ARISTA
 } bgpq_vendor_t;
@@ -91,6 +92,8 @@ struct bgpq_expander {
 	struct sx_radix_tree	 	*tree;
 	int			 	 family;
 	char				*sources;
+	char				*defaultsources;
+	unsigned int			 usesource;
 	uint32_t		 	 asnumber;
 	int			 	 aswidth;
 	char				*name;
@@ -126,6 +129,10 @@ int bgpq_expander_add_prefix(struct bgpq_expander *b, char *prefix);
 int bgpq_expander_add_prefix_range(struct bgpq_expander *b, char *prefix);
 int bgpq_expander_add_stop(struct bgpq_expander *b, char *object);
 
+char* bgpq_get_asset(char *object);
+char* bgpq_get_rset(char *object);
+char* bgpq_get_source(char *object);
+
 int bgpq_expand(struct bgpq_expander *b);
 
 void bgpq4_print_prefixlist(FILE *f, struct bgpq_expander *b);
